==> apache-kie-10.0.0-incubating-sources.zip: incubator-kie-tools/packages/runtime-tools-shared-enveloped-components/src/formDisplayer/envelope/components/ResourcesContainer/ResourcesContainer.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import React, { ReactElement } from "react";
import { Helmet } from "react-helmet";
import { FormResources } from "../../../api";

interface ResourcesContainerProps {
  resources: FormResources;
}

const ResourcesContainer: React.FC<ResourcesContainerProps> = ({ resources }) => {
  const scriptTags: ReactElement[] = [];
  const styleTags: ReactElement[] = [];

  if (resources) {
    for (const key in resources.styles) {
      styleTags.push(<link rel={"stylesheet"} href={resources.styles[key]} key={key} />);
    }
    for (const key in resources.scripts) {
      scriptTags.push(<script src={resources.scripts[key]} type={"text/javascript"} async={false} key={key} />);
    }
  }

  return (
    <Helmet>
      {styleTags}
      {scriptTags}
    </Helmet>
  );
};

export default ResourcesContainer;

==> apache-kie-10.1.0-incubating-sources.zip: incubator-kie-tools/packages/runtime-tools-shared-enveloped-components/src/formDisplayer/envelope/components/ResourcesContainer/ResourcesContainer.tsx <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import React, { ReactElement } from "react";
import { Helmet } from "react-helmet";
import { FormResources } from "@kie-tools/runtime-tools-shared-gateway-api/src/types";

interface ResourcesContainerProps {
  resources: FormResources;
}

const ResourcesContainer: React.FC<ResourcesContainerProps> = ({ resources }) => {
  const scriptTags: ReactElement[] = [];
  const styleTags: ReactElement[] = [];

  if (resources) {
    for (const key in resources.styles) {
      styleTags.push(<link rel={"stylesheet"} href={resources.styles[key]} key={key} />);
    }
    for (const key in resources.scripts) {
      scriptTags.push(<script src={resources.scripts[key]} type={"text/javascript"} async={false} key={key} />);
    }
  }

  return (
    <Helmet>
      {styleTags}
      {scriptTags}
    </Helmet>
  );
};

export default ResourcesContainer;
